==> dl.php?src=linea21_1_0.zip: linea21/yellowpages/mail_actions.php <==
<?php
//////////// Check Inclusion de pages //////////// 
if (!function_exists('AuthenthificationProcess')){ 
include_once("../lib/lib_common.php");
ReloadIndex('admin');
}
//////////// 
		/** Prparation du mail
		* $email_html_body
		* $email_text_body
		* $email_subject
		* $email_dest
		**/
		
		$req_det= SQL_getdetyp($yp_id);
		$result=$sql_object->DBSelect($req_det);

        $email_html_body= $GLOBALS['lang']['yp']['mail_entete']."<br />";
		$email_html_body.="<dl>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['theme'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['theme_name'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['name2'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_name'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['activity'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_activity'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['street'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_street'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['postal_code'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_postal_code'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['city'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_city'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['country'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_country'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['phone'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_phone'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['fax'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_fax'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['email'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_email'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['website'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_website'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['divers']['date_crea'].": </dt>\n";
		$email_html_body.="<dd>".$result[0]['yellowp_date_crea']."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['divers']['statut'].": </dt>\n";
		$email_html_body.="<dd>".display_statut($result[0]['yellowp_statut'])."</dd></dl>\n";
		$email_html_body.=	"<br />".$GLOBALS['lang']['yp']['mail_body1'].": <a href=\"".SITE_CITY_NAME."\">".SITE_CITY_URL."</a><br />";
		$email_html_body.=	$GLOBALS['lang']['yp']['mail_bottom'].": <a href=\"".SITE_CITY_MAIL."\">".SITE_CITY_MAIL."</a><br />\n";
		
		
		$email_text_body=$GLOBALS['lang']['yp']['mail_entete']."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['theme'].": ".formatText($result[0]['theme_name'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['name2'].": ".formatText($result[0]['yellowp_name'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['activity'].": ".formatText($result[0]['yellowp_activity'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['street'].": ".formatText($result[0]['yellowp_street'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['postal_code'].": ".formatText($result[0]['yellowp_postal_code'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['city'].": ".formatText($result[0]['yellowp_city'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['country'].": ".formatText($result[0]['yellowp_country'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['phone'].": ".formatText($result[0]['yellowp_phone'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['fax'].": ".formatText($result[0]['yellowp_fax'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['email'].": ".formatText($result[0]['yellowp_email'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['website'].": ".formatText($result[0]['yellowp_website'])."\n";
		$email_text_body.=$GLOBALS['lang']['divers']['date_crea'].": ".$result[0]['yellowp_date_crea']."\n";
		$email_text_body.=$GLOBALS['lang']['divers']['statut'].": ".display_statut($result[0]['yellowp_statut'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['mail_body1'].SITE_CITY_URL."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['mail_bottom'].SITE_CITY_MAIL."\n";	
		

		$email_subject = "confirmation de votre inscription sur ".SITE_CITY_NAME;
		$email_dest = $result[0]['yellowp_email'];
?>

==> dl.php?src=linea21_1_1.zip: linea21/yellowpages/mail_actions.php <==
<?php
//////////// Check Inclusion de pages //////////// 
if (!function_exists('AuthenthificationProcess')){ 
include_once("../lib/lib_common.php");
ReloadIndex('admin');
}
//////////// 
		/** Préparation du mail
		* $email_html_body
		* $email_text_body
		* $email_subject
		* $email_dest
		**/
		
		$req_det= SQL_getdetyp($yp_id);
		$result=$sql_object->DBSelect($req_det);

		$email_html_body= $GLOBALS['lang']['yp']['mail_entete']."<br />";
		$email_html_body.="<dl>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['theme'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['theme_name'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['name2'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_name'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['activity'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_activity'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['street'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_street'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['postal_code'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_postal_code'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['city'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_city'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['country'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_country'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['phone'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_phone'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['fax'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_fax'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['email'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_email'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['yp']['website'].": </dt>\n";
		$email_html_body.="<dd>".formatText($result[0]['yellowp_website'])."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['divers']['date_crea'].": </dt>\n";
		$email_html_body.="<dd>".$result[0]['yellowp_date_crea']."</dd>\n";
		$email_html_body.="<dt>".$GLOBALS['lang']['divers']['statut'].": </dt>\n";
		$email_html_body.="<dd>".display_statut($result[0]['yellowp_statut'])."</dd></dl>\n";
		$email_html_body.="<br />".$GLOBALS['lang']['yp']['mail_body1'].": <a href=\"".SITE_CITY_URL."\">".SITE_CITY_NAME."</a><br />";
		$email_html_body.=$GLOBALS['lang']['yp']['mail_bottom'].": <a href=\"mailto:".SITE_CITY_MAIL."\">".SITE_CITY_MAIL."</a><br />\n";
		
		
		$email_text_body=$GLOBALS['lang']['yp']['mail_entete']."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['theme'].": ".formatText($result[0]['theme_name'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['name2'].": ".formatText($result[0]['yellowp_name'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['activity'].": ".formatText($result[0]['yellowp_activity'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['street'].": ".formatText($result[0]['yellowp_street'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['postal_code'].": ".formatText($result[0]['yellowp_postal_code'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['city'].": ".formatText($result[0]['yellowp_city'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['country'].": ".formatText($result[0]['yellowp_country'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['phone'].": ".formatText($result[0]['yellowp_phone'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['fax'].": ".formatText($result[0]['yellowp_fax'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['email'].": ".formatText($result[0]['yellowp_email'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['website'].": ".formatText($result[0]['yellowp_website'])."\n";
		$email_text_body.=$GLOBALS['lang']['divers']['date_crea'].": ".$result[0]['yellowp_date_crea']."\n";
		$email_text_body.=$GLOBALS['lang']['divers']['statut'].": ".display_statut($result[0]['yellowp_statut'])."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['mail_body1'].SITE_CITY_URL."\n";
		$email_text_body.=$GLOBALS['lang']['yp']['mail_bottom'].SITE_CITY_MAIL."\n";	
		

		$email_subject = $GLOBALS['lang']['yp']['confirm_subscription'] . ' ' . SITE_CITY_NAME;
		$email_dest = $result[0]['yellowp_email'];
?>
